@@ -12,7 +12,7 @@ from pydantic import BaseModel
 from ..models.generated import (
     TasksCreateParams, TasksSendParams, TasksGetParams,
     StreamStartParams, StreamMessageParams,
-    JsonRpcRequest, JsonRpcResponse, RpcError
+    JsonRpcRequest, JsonRpcResponse, RpcError, Jsonrpc, Method
 )
 from ..core.json_rpc import JsonRpcError, JsonRpcProcessor
 from .auth import OAuth2Handler
@@ -79,8 +79,8 @@ class ACPClient:
             TimeoutError: If the request times out
         """
         request = JsonRpcRequest(
-            jsonrpc="2.0",
-            method="tasks.create",
+            jsonrpc=Jsonrpc.field_2_0,
+            method=Method.tasks_create,
             params=params.model_dump(by_alias=True),
             id=self._generate_id()
         )
@@ -91,8 +91,8 @@ class ACPClient:
     async def tasks_send(self, params: TasksSendParams) -> Dict[str, Any]:
         """Send message to existing task."""
         request = JsonRpcRequest(
-            jsonrpc="2.0",
-            method="tasks.send",
+            jsonrpc=Jsonrpc.field_2_0,
+            method=Method.tasks_send,
             params=params.model_dump(by_alias=True),
             id=self._generate_id()
         )
@@ -103,8 +103,8 @@ class ACPClient:
     async def tasks_get(self, params: TasksGetParams) -> Dict[str, Any]:
         """Get task status and result."""
         request = JsonRpcRequest(
-            jsonrpc="2.0",
-            method="tasks.get",
+            jsonrpc=Jsonrpc.field_2_0,
+            method=Method.tasks_get,
             params=params.model_dump(by_alias=True),
             id=self._generate_id()
         )
@@ -115,8 +115,8 @@ class ACPClient:
     async def stream_start(self, params: StreamStartParams) -> Dict[str, Any]:
         """Start real-time stream with agent."""
         request = JsonRpcRequest(
-            jsonrpc="2.0",
-            method="stream.start",
+            jsonrpc=Jsonrpc.field_2_0,
+            method=Method.stream_start,
             params=params.model_dump(by_alias=True),
             id=self._generate_id()
         )
@@ -127,8 +127,8 @@ class ACPClient:
     async def stream_message(self, params: StreamMessageParams) -> Dict[str, Any]:
         """Send message in active stream."""
         request = JsonRpcRequest(
-            jsonrpc="2.0",
-            method="stream.message",
+            jsonrpc=Jsonrpc.field_2_0,
+            method=Method.stream_message,
             params=params.model_dump(by_alias=True),
             id=self._generate_id()
         )
